package ch.zhaw.gartenverwaltung.types;

import java.util.Date;
import java.util.Optional;

/**
 * Models a Task
 * May be created using the builder pattern.
 */
public class Task {
    private long id;
    private final String name;
    private final String description;
    private final Date startDate;
    private Integer interval;
    private Date endDate;

    public Task(String name, String description, Date startDate) {
        this.name = name;
        this.description = description;
        this.startDate = endDate;
    }

    // Builder-pattern-style setters
    public Task withId(long id) {
        this.id = id;
        return this;
    }
    public Task withInterval(int interval) {
        this.interval = interval;
        return this;
    }
    public Task withEndDate(Date endDate) {
        this.endDate = endDate;
        return this;
    }

    // Getters
    public long getId() { return id; }
    public String getName() { return name; }
    public String getDescription() { return description; }
    public Date getStartDate() { return startDate; }

    public Optional<Integer> getInterval() {
        return Optional.ofNullable(interval);
    }
    public Optional<Date> getEndDate() {
        return Optional.ofNullable(endDate);
    }
}
